import 'dart:math';
import 'package:f_k_chart/flutter_k_chart/entity/k_line_entity.dart';
import 'package:rxdart/rxdart.dart';
import 'package:f_k_chart/common/bloc_provider.dart';
import 'package:f_k_chart/model/kline_model.dart';
import 'package:f_k_chart/manager/kline_data_calculate_manager.dart';
import 'package:f_k_chart/model/kline_data.dart';

import 'chart_style.dart';

class KlineWidgetStatus {
  bool isLongPress;
  double selectX;
  double pointWidth;

  KlineWidgetStatus({
    this.isLongPress = false,
    this.selectX = 0.0,
    this.pointWidth = ChartStyle.pointWidth,
  });
}

class KlineScrollBloc extends BlocBase {
  BehaviorSubject<List<KLineEntity>> _klineListController =
      BehaviorSubject<List<KLineEntity>>();
  BehaviorSubject<List<KLineEntity>> _klineCurrentListController =
      BehaviorSubject<List<KLineEntity>>();

  PublishSubject<KlineWidgetStatus> _klineWidgetStatusController =
      PublishSubject<KlineWidgetStatus>();

  Sink<KlineWidgetStatus> get _inKlineWidgetStatus =>
      _klineWidgetStatusController.sink;

  Stream<KlineWidgetStatus> get outKlineWidgetStatus =>
      _klineWidgetStatusController.stream;
  KlineWidgetStatus mCurrentWidgetStatus = KlineWidgetStatus();

  Sink<List<KLineEntity>> get _inklineList => _klineListController.sink;

  Stream<List<KLineEntity>> get outklineList => _klineListController.stream;

  Sink<List<KLineEntity>> get _inCurrentKlineList =>
      _klineCurrentListController.sink;

  Stream<List<KLineEntity>> get outCurrentKlineList =>
      _klineCurrentListController.stream;

  List<KLineEntity> visibleKlineList = List();
  List<KLineEntity> allKlineList = List();

  //当前k线滑到的位置
  int currentIndex = 0;

  //当前线宽
  double rectWidth = ChartStyle.pointWidth;
  double screenWidth = 375;
  double userFriendlyMinPointWidth = 8.0;

  double maxRectWidth;
  double minRectWidth;

  int gap = 1;

  KlineScrollBloc() {
    initData();
  }

  void initData() {}

  @override
  void dispose() {
    _klineListController.close();
    _klineCurrentListController.close();
    _klineWidgetStatusController.close();
  }

  void updateDataList(List<KLineEntity> dataList) {
//    if (dataList != null && dataList.length > 0) {
    if (dataList != null && dataList is List) {
      if (dataList.length - allKlineList.length > 0) {
        currentIndex = currentIndex + (dataList.length - allKlineList.length);
      }
      allKlineList.clear();
      for (var item in dataList) {
        allKlineList.add(item);
      }
      _inklineList.add(allKlineList);
    }
  }

  void setCurrentIndex(int index) {
    currentIndex = index;
  }

  int getCurrentIndex() {
    return currentIndex;
  }

  int getGap() {
    return gap;
  }

  void setMaxRectWidth(double maxRectWidth) {
    this.maxRectWidth = maxRectWidth;
  }

  void setMinRectWidth(double minRectWidth) {
    this.minRectWidth = minRectWidth;
  }

  void setKlineWidgetStatus(
      {bool isLongPress, double selectX, double pointWidth}) {
    if (isLongPress != null) {
      mCurrentWidgetStatus.isLongPress = isLongPress;
    }
    if (selectX != null) {
      mCurrentWidgetStatus.selectX = selectX;
    }
    if (pointWidth != null) {
      mCurrentWidgetStatus.pointWidth = pointWidth;
    }
    _inKlineWidgetStatus.add(mCurrentWidgetStatus);
  }

  static int calculateVisiblePointCountFitScreenWidth(
      double screenWidth, double pointWidth) {
    int count = (screenWidth ~/ pointWidth).toInt() + 1;
    return count;
  }

  void calculateVisibleKlineList(
      int startIndex, int count, int allPointsCount) {
    if (count == null) return;
    int currentIndex = startIndex;
    if (currentIndex < 0) currentIndex = 0;
    if (count >= allPointsCount) {
      currentIndex = 0;
      count = allPointsCount;
    } else {
      if (currentIndex + count > allPointsCount) {
        currentIndex = allPointsCount - count;
      }
    }
    setCurrentIndex(currentIndex);
    getSubKlineList(currentIndex, currentIndex + count);
  }

  void setScreenWidth(double width) {
    screenWidth = width;

    int count =
        calculateVisiblePointCountFitScreenWidth(screenWidth, rectWidth);
    calculateVisibleKlineList(currentIndex, count, allKlineList.length);
  }

  void getSubKlineList(int from, int to) {
    List<KLineEntity> list = this.allKlineList;
    visibleKlineList = list.sublist(from, to);
    _inCurrentKlineList.add(visibleKlineList);
  }

  void setRectWidth(double width) {
    if (maxRectWidth != null && width > maxRectWidth) return;
    if (minRectWidth != null && width < minRectWidth) return;


    if (width < userFriendlyMinPointWidth) {
      gap = userFriendlyMinPointWidth ~/ width;
    } else {
      gap = 1;
    }

    rectWidth = width;
    setKlineWidgetStatus(pointWidth: rectWidth);
  }
}
